@@ -23,7 +23,7 @@ messages about granted attribute access.
 Note that the ZOPE_WATCH_CHECKERS mechanism will eventually be
 replaced with a more general security auditing mechanism.
 
-$Id: checker.py 105559 2009-11-10 14:35:15Z jim $
+$Id: checker.py 107750 2010-01-06 18:10:43Z kobold $
 """
 import os
 import sys
@@ -32,7 +32,6 @@ import datetime
 import decimal
 import weakref
 
-from zope.exceptions import DuplicationError
 import zope.interface.interface
 import zope.interface.interfaces
 import zope.interface.declarations
@@ -46,6 +45,12 @@ from zope.security.interfaces import Unauthorized, ForbiddenAttribute
 from zope.security._definitions import thread_local
 from zope.security._proxy import _Proxy as Proxy, getChecker
 
+try:
+    from zope.exceptions import DuplicationError
+except ImportError:
+    class DuplicationError(Exception):
+        """A duplicate registration was attempted"""
+
 if os.environ.get('ZOPE_WATCH_CHECKERS'):
     try:
         WATCH_CHECKERS = int(os.environ.get('ZOPE_WATCH_CHECKERS'))
